@@ -1,6 +1,6 @@
 package Business::CardInfo;
 BEGIN {
-  $Business::CardInfo::VERSION = '0.08';
+  $Business::CardInfo::VERSION = '0.09';
 }
 use Moose;
 use Moose::Util::TypeConstraints;
@@ -50,18 +50,18 @@ sub _build_type {
     446213 .. 446254, 446257 .. 446272,446274 .. 446283, 446286, 446294, 450875, 
     453978, 453979, 454313, 454432 .. 454435, 454742, 456725 .. 456745, 
     465830 .. 465879, 465901 .. 465950,475110 .. 475159, 475710 .. 475759, 
-    476220 .. 476269, 476340 .. 476389, 484409 .. 484410, 484427, 
+    476220 .. 476269, 476340 .. 476389, 484427, 
     490960 .. 490979, 492181 .. 492182, 492186, 498824, 499902, 465942,
     407704, 407705, 408367, 445190, 456705, 456706, 474503,
     474551, 475183, 499844 .. 499846, 460024, 421682, 441078, 445191, 445192, 
     458046, 480240, 499806, 484412, 484415 .. 484417, 495065, 495067, 
-    495090 .. 495094, 446291,446292, 408456,408457
+    495090 .. 495094, 446291, 446292, 408456, 408457, 477106
   ]);
   return "Visa Electron" if $self->_search([
     417500, 400115, 400837 .. 400839, 412921 .. 412923, 417935, 419740, 
-    419741, 419773 .. 419776, 424519, 424962, 424963, 444000, 484406 .. 484408,
+    419741, 419773 .. 419776, 424519, 424962, 424963, 444000,
     484428 .. 484455, 491730 .. 491759, 491880, 4917, 4913,
-    4508, 4844,  484411 .. 484413, 484414, 484418 .. 484426]);
+    4508, 4844,  484406 .. 484411, 484413, 484414, 484418 .. 484426]);
   return "MasterCard Debit" if $self->_search([
     512499, 512746, 516001, 516730, 516979, 517000, 517049, 524342, 527591,
     535110 .. 535309, 535420 .. 535819, 537210 .. 537609, 557347 .. 557496,
@@ -107,7 +107,7 @@ Business::CardInfo - Get/Validate data from credit & debit cards
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
